Crate rhizomedb_wasm

rhizome

Modules

builder
tuple

Macros

console_log
Calls the wasm_bindgen console.log.
value
Return a representation of an object owned by JS.

Structs

Cid
Rhizome

Functions

log
set_panic_hook
Panic hook lets us get better error messages if our Rust code ever panics.